@@ -1,10 +1,47 @@
+
 /*
- * dlep_base_radio.c
+ * The olsr.org Optimized Link-State Routing daemon version 2 (olsrd2)
+ * Copyright (c) 2004-2015, the olsr.org team - see HISTORY file
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
+ *
+ * * Redistributions of source code must retain the above copyright
+ *   notice, this list of conditions and the following disclaimer.
+ * * Redistributions in binary form must reproduce the above copyright
+ *   notice, this list of conditions and the following disclaimer in
+ *   the documentation and/or other materials provided with the
+ *   distribution.
+ * * Neither the name of olsr.org, olsrd nor the names of its
+ *   contributors may be used to endorse or promote products derived
+ *   from this software without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+ * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+ * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
+ * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
+ * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
+ * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
+ * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
+ * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
+ * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
+ * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
+ * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+ * POSSIBILITY OF SUCH DAMAGE.
+ *
+ * Visit http://www.olsr.org for more information.
+ *
+ * If you find this software useful feel free to make a donation
+ * to the project. For more information see the website or contact
+ * the copyright holders.
  *
- *  Created on: Jun 29, 2015
- *      Author: rogge
  */
 
+/**
+ * @file
+ */
 
 #include "common/common_types.h"
 #include "common/avl.h"
@@ -44,9 +81,8 @@ static int _radio_write_peer_offer(struct dlep_extension *,
 static int _radio_write_peer_init_ack(struct dlep_extension *,
     struct dlep_session *session, const struct netaddr *);
 
-static void _l2_neigh_added_to_session(
-    struct dlep_session *session, struct oonf_layer2_neigh *l2neigh,
-      struct oonf_layer2_destination *l2dest, const struct netaddr *mac);
+static void _l2_neigh_added_to_session(struct dlep_session *session,
+    struct oonf_layer2_neigh *l2neigh, const struct netaddr *mac);
 static void _l2_neigh_added(struct oonf_layer2_neigh *l2neigh,
       struct oonf_layer2_destination *l2dest, const struct netaddr *mac);
 
@@ -147,6 +183,9 @@ static struct oonf_class_extension _layer2_dst_listener = {
 
 static struct dlep_extension *_base;
 
+/**
+ * Initialize the radios DLEP base protocol extension
+ */
 void
 dlep_base_proto_radio_init(void) {
   _base = dlep_base_proto_init();
@@ -160,6 +199,10 @@ dlep_base_proto_radio_init(void) {
   _base->cb_session_cleanup_radio = _cb_cleanup_radio;
 }
 
+/**
+ * Callback to initialize the radio session
+ * @param session dlep session
+ */
 static void
 _cb_init_radio(struct dlep_session *session) {
   if (session->restrict_signal == DLEP_PEER_INITIALIZATION) {
@@ -173,11 +216,21 @@ _cb_init_radio(struct dlep_session *session) {
   session->cb_destination_timeout = _cb_destination_timeout;
 }
 
+/**
+ * Callback to cleanup the radio session
+ * @param session dlep session
+ */
 static void
 _cb_cleanup_radio(struct dlep_session *session) {
   dlep_base_proto_stop_timers(session);
 }
 
+/**
+ * Process the peer discovery signal
+ * @param ext (this) dlep extension
+ * @param session dlep session
+ * @return -1 if an error happened, 0 otherwise
+ */
 static int
 _radio_process_peer_discovery(
     struct dlep_extension *ext __attribute__((unused)),
@@ -189,6 +242,12 @@ _radio_process_peer_discovery(
   return dlep_session_generate_signal(session, DLEP_PEER_OFFER, NULL);
 }
 
+/**
+ * Process the peer initialization message
+ * @param ext (this) dlep extension
+ * @param session dlep session
+ * @return -1 if an error happened, 0 otherwise
+ */
 static int
 _radio_process_peer_init(
     struct dlep_extension *ext __attribute__((unused)),
@@ -199,6 +258,10 @@ _radio_process_peer_init(
   struct dlep_parser_value *value;
   const uint8_t *ptr;
 
+#ifdef OONF_LOG_DEBUG_INFO
+  struct netaddr_str nbuf;
+#endif
+
   if (session->restrict_signal != DLEP_PEER_INITIALIZATION) {
     /* ignore unless we are in initialization mode */
     return 0;
@@ -228,6 +291,9 @@ _radio_process_peer_init(
       return -1;
     }
   }
+  else if (dlep_session_update_extensions(session, NULL, 0)) {
+    return -1;
+  }
 
   if (dlep_session_generate_signal(
       session, DLEP_PEER_INITIALIZATION_ACK, NULL)) {
@@ -239,23 +305,32 @@ _radio_process_peer_init(
   if (l2net) {
     avl_for_each_element(&l2net->neighbors, l2neigh, _node) {
       if (session->cfg.send_neighbors) {
-        _l2_neigh_added_to_session(session, l2neigh, NULL, &l2neigh->addr);
+        OONF_DEBUG(session->log_source, "Add local neighbor: %s",
+            netaddr_to_string(&nbuf, &l2neigh->addr));
+        _l2_neigh_added_to_session(session, l2neigh, &l2neigh->addr);
       }
 
       if (session->cfg.send_proxied) {
         avl_for_each_element(&l2neigh->destinations, l2dest, _node) {
+          OONF_DEBUG(session->log_source, "Add proxied neighbor: %s",
+              netaddr_to_string(&nbuf, &l2dest->destination));
           _l2_neigh_added_to_session(
-              session, l2neigh, l2dest, &l2dest->destination);
+              session, l2neigh, &l2dest->destination);
         }
       }
     }
   }
-
   session->next_restrict_signal = DLEP_ALL_SIGNALS;
 
   return 0;
 }
 
+/**
+ * Process the peer update message
+ * @param ext (this) dlep extension
+ * @param session dlep session
+ * @return -1 if an error happened, 0 otherwise
+ */
 static int
 _radio_process_peer_update(
     struct dlep_extension *ext __attribute__((unused)),
@@ -264,6 +339,12 @@ _radio_process_peer_update(
   return dlep_session_generate_signal(session, DLEP_PEER_UPDATE_ACK, NULL);
 }
 
+/**
+ * Process the peer update ack message
+ * @param ext (this) dlep extension
+ * @param session dlep session
+ * @return always 0
+ */
 static int
 _radio_process_peer_update_ack(
     struct dlep_extension *ext __attribute__((unused)),
@@ -272,6 +353,12 @@ _radio_process_peer_update_ack(
   return 0;
 }
 
+/**
+ * Process the destination up message
+ * @param ext (this) dlep extension
+ * @param session dlep session
+ * @return -1 if an error happened, 0 otherwise
+ */
 static int
 _radio_process_destination_up(
     struct dlep_extension *ext __attribute__((unused)),
@@ -287,6 +374,12 @@ _radio_process_destination_up(
       session, DLEP_DESTINATION_UP_ACK, &mac);
 }
 
+/**
+ * Process the destination up ack message
+ * @param ext (this) dlep extension
+ * @param session dlep session
+ * @return -1 if an error happened, 0 otherwise
+ */
 static int
 _radio_process_destination_up_ack(
     struct dlep_extension *ext __attribute__((unused)),
@@ -313,6 +406,12 @@ _radio_process_destination_up_ack(
   return 0;
 }
 
+/**
+ * Process the destination down message
+ * @param ext (this) dlep extension
+ * @param session dlep session
+ * @return -1 if an error happened, 0 otherwise
+ */
 static int
 _radio_process_destination_down(
     struct dlep_extension *ext __attribute__((unused)),
@@ -327,6 +426,12 @@ _radio_process_destination_down(
       session, DLEP_DESTINATION_DOWN_ACK, &mac);
 }
 
+/**
+ * Process the destination down ack message
+ * @param ext (this) dlep extension
+ * @param session dlep session
+ * @return -1 if an error happened, 0 otherwise
+ */
 static int
 _radio_process_destination_down_ack(
     struct dlep_extension *ext __attribute__((unused)),
@@ -347,20 +452,41 @@ _radio_process_destination_down_ack(
   return 0;
 }
 
+/**
+ * Process the destination update message
+ * @param ext (this) dlep extension
+ * @param session dlep session
+ * @return always 0
+ */
 static int
 _radio_process_destination_update(
     struct dlep_extension *ext __attribute__((unused)),
     struct dlep_session *session __attribute__((unused))) {
+  /* TODO: IP address change processing ? */
   return 0;
 }
 
+/**
+ * Process the link characteristic message
+ * @param ext (this) dlep extension
+ * @param session dlep session
+ * @return -1 if an error happened, 0 otherwise
+ */
 static int
 _radio_process_link_char_request(
     struct dlep_extension *ext __attribute__((unused)),
     struct dlep_session *session __attribute__((unused))) {
+  /* TODO: Link characteristic processing ? */
   return 0;
 }
 
+/**
+ * Generate a peer offer signal
+ * @param ext (this) dlep extension
+ * @param session dlep session
+ * @param addr mac address the message should refer to
+ * @return -1 if an error happened, 0 otherwise
+ */
 static int
 _radio_write_peer_offer(
     struct dlep_extension *ext __attribute__((unused)),
@@ -378,18 +504,27 @@ _radio_write_peer_offer(
 
   netaddr_from_socket(&local_addr, &radio_if->tcp.socket_v4.local_socket);
   if (netaddr_get_address_family(&local_addr) == AF_INET) {
+    /* no support for TLS at the moment */
     dlep_writer_add_ipv4_conpoint_tlv(&session->writer,
-        &local_addr, radio_if->tcp_config.port);
+        &local_addr, radio_if->tcp_config.port, false);
   }
 
   netaddr_from_socket(&local_addr, &radio_if->tcp.socket_v6.local_socket);
   if (netaddr_get_address_family(&local_addr) == AF_INET6) {
+    /* no support for TLS at the moment */
     dlep_writer_add_ipv6_conpoint_tlv(&session->writer,
-        &local_addr, radio_if->tcp_config.port);
+        &local_addr, radio_if->tcp_config.port, false);
   }
   return 0;
 }
 
+/**
+ * Generate a peer init ack signal
+ * @param ext (this) dlep extension
+ * @param session dlep session
+ * @param addr mac address the message should refer to
+ * @return -1 if an error happened, 0 otherwise
+ */
 static int
 _radio_write_peer_init_ack(
     struct dlep_extension *ext __attribute__((unused)),
@@ -417,21 +552,21 @@ _radio_write_peer_init_ack(
   return 0;
 }
 
+/**
+ * Helper function to add a layer2 neighbor to a dlep session
+ * @param session dlep session
+ * @param l2neigh layer2 neighbor
+ * @param mac MAC address of other endpoint
+ */
 static void
 _l2_neigh_added_to_session(struct dlep_session *session,
-    struct oonf_layer2_neigh *l2neigh,
-      struct oonf_layer2_destination *l2dest, const struct netaddr *mac) {
+    struct oonf_layer2_neigh *l2neigh, const struct netaddr *mac) {
   struct dlep_local_neighbor *local;
 
   local = dlep_session_add_local_neighbor(session, mac);
 
   if (local) {
-    if (l2dest) {
-      memcpy(&local->neigh_addr, &l2neigh->addr, sizeof(local->neigh_addr));
-    }
-    else {
-      netaddr_invalidate(&local->neigh_addr);
-    }
+    memcpy(&local->neigh_addr, &l2neigh->addr, sizeof(local->neigh_addr));
 
     dlep_session_generate_signal(session, DLEP_DESTINATION_UP, mac);
     local->state = DLEP_NEIGHBOR_UP_SENT;
@@ -440,6 +575,12 @@ _l2_neigh_added_to_session(struct dlep_session *session,
   }
 }
 
+/**
+ * Helper function triggered for a new layer2 neighbor
+ * @param l2neigh layer2 neighbor
+ * @param l2dest layer2 destination (might be NULL)
+ * @param mac MAC address of other endpoint
+ */
 static void
 _l2_neigh_added(struct oonf_layer2_neigh *l2neigh,
     struct oonf_layer2_destination *l2dest, const struct netaddr *mac) {
@@ -458,10 +599,16 @@ _l2_neigh_added(struct oonf_layer2_neigh *l2neigh,
     if (!l2dest && !radio_session->session.cfg.send_neighbors) {
       continue;
     }
-    _l2_neigh_added_to_session(&radio_if->interf.session, l2neigh, l2dest, mac);
+    _l2_neigh_added_to_session(&radio_if->interf.session, l2neigh, mac);
   }
 }
 
+/**
+ * Helper function triggered when a layer2 neighbor changed
+ * @param l2neigh layer2 neighbor
+ * @param l2dest layer2 destination (might be NULL)
+ * @param mac MAC address of other endpoint
+ */
 static void
 _l2_neigh_changed(struct oonf_layer2_neigh *l2neigh,
     struct oonf_layer2_destination *l2dest, const struct netaddr *mac) {
@@ -486,12 +633,7 @@ _l2_neigh_changed(struct oonf_layer2_neigh *l2neigh,
         &radio_session->session, mac);
 
     if (local) {
-      if (l2dest) {
-        memcpy(&local->neigh_addr, &l2neigh->addr, sizeof(local->neigh_addr));
-      }
-      else {
-        netaddr_invalidate(&local->neigh_addr);
-      }
+      memcpy(&local->neigh_addr, &l2neigh->addr, sizeof(local->neigh_addr));
 
       switch (local->state) {
         case DLEP_NEIGHBOR_UP_SENT:
@@ -519,6 +661,12 @@ _l2_neigh_changed(struct oonf_layer2_neigh *l2neigh,
   }
 }
 
+/**
+ * Helper function triggered when a layer2 neighbor is removed
+ * @param l2neigh layer2 neighbor
+ * @param l2dest layer2 destination (might be NULL)
+ * @param mac MAC address of other endpoint
+ */
 static void
 _l2_neigh_removed(struct oonf_layer2_neigh *l2neigh,
     struct oonf_layer2_destination *l2dest, const struct netaddr *mac) {
@@ -557,6 +705,10 @@ _l2_neigh_removed(struct oonf_layer2_neigh *l2neigh,
 
 }
 
+/**
+ * Callback triggered when a layer2 neighbor object has been added
+ * @param ptr layer2 neighbor
+ */
 static void
 _cb_l2_neigh_added(void *ptr) {
   struct oonf_layer2_neigh *l2neigh = ptr;
@@ -564,6 +716,10 @@ _cb_l2_neigh_added(void *ptr) {
   _l2_neigh_added(l2neigh, NULL, &l2neigh->addr);
 }
 
+/**
+ * Callback triggered when a layer2 neighbor object has been changed
+ * @param ptr layer2 neighbor
+ */
 static void
 _cb_l2_neigh_changed(void *ptr) {
   struct oonf_layer2_neigh *l2neigh;
@@ -577,6 +733,10 @@ _cb_l2_neigh_changed(void *ptr) {
   }
 }
 
+/**
+ * Callback triggered when a layer2 neighbor object has been removed
+ * @param ptr layer2 neighbor
+ */
 static void
 _cb_l2_neigh_removed(void *ptr) {
   struct oonf_layer2_neigh *l2neigh = ptr;
@@ -584,6 +744,10 @@ _cb_l2_neigh_removed(void *ptr) {
   _l2_neigh_removed(l2neigh, NULL, &l2neigh->addr);
 }
 
+/**
+ * Callback triggered when a layer2 destination object has been added
+ * @param ptr layer2 destination
+ */
 static void
 _cb_l2_dst_added(void *ptr) {
   struct oonf_layer2_destination *l2dst = ptr;
@@ -591,6 +755,10 @@ _cb_l2_dst_added(void *ptr) {
   _l2_neigh_added(l2dst->neighbor, NULL, &l2dst->destination);
 }
 
+/**
+ * Callback triggered when a layer2 destination object has been removed
+ * @param ptr layer2 destination
+ */
 static void
 _cb_l2_dst_removed(void *ptr) {
   struct oonf_layer2_destination *l2dst = ptr;
@@ -598,6 +766,11 @@ _cb_l2_dst_removed(void *ptr) {
   _l2_neigh_removed(l2dst->neighbor, NULL, &l2dst->destination);
 }
 
+/**
+ * Callback triggered when a destination up/down ack times out
+ * @param session dlep session
+ * @param local local DLEP neighbor
+ */
 static void
 _cb_destination_timeout(struct dlep_session *session,
     struct dlep_local_neighbor *local) {
