@@ -39,6 +39,10 @@
  *
  */
 
+/**
+ * @file
+ */
+
 #ifndef NL80211_LISTENER_H_
 #define NL80211_LISTENER_H_
 
@@ -47,6 +51,7 @@
 #include "subsystems/oonf_interface.h"
 #include "subsystems/oonf_layer2.h"
 
+/*! subsystem identifier */
 #define OONF_NL80211_LISTENER_SUBSYSTEM "nl80211_listener"
 
 /**
@@ -62,8 +67,8 @@ struct nl80211_if {
   /*! layer2 network object of interface */
   struct oonf_layer2_net *l2net;
 
-  /*! physical interface id, might be different because of VLANs */
-  int phy_if;
+  /*! physical interface index */
+  int wifi_phy_if;
 
   /*! maximum tx rate */
   uint64_t max_tx;
@@ -94,7 +99,6 @@ bool nl80211_change_l2net_data(struct oonf_layer2_net *l2net,
 bool nl80211_change_l2net_neighbor_default(struct oonf_layer2_net *l2net,
     enum oonf_layer2_neighbor_index idx, uint64_t value);
 void nl80211_cleanup_l2neigh_data(struct oonf_layer2_neigh *l2neigh);
-void nl80211_cleanup_l2net_data(struct oonf_layer2_net *l2net);
 bool nl80211_change_l2neigh_data(struct oonf_layer2_neigh *l2neigh,
     enum oonf_layer2_neighbor_index idx, uint64_t value);
 
@@ -103,8 +107,8 @@ bool nl80211_change_l2neigh_data(struct oonf_layer2_neigh *l2neigh,
  * @returns nl80211 interface index
  */
 static INLINE unsigned
-nl80211_get_if_index(struct nl80211_if *interf) {
-  return interf->if_listener.interface->data.index;
+nl80211_get_if_baseindex(struct nl80211_if *interf) {
+  return interf->if_listener.interface->data.base_index;
 }
 
 #endif /* NL80211_LISTENER_H_ */
