@@ -39,6 +39,10 @@
  *
  */
 
+/**
+ * @file
+ */
+
 #include "common/common_types.h"
 #include "common/avl.h"
 #include "common/netaddr.h"
@@ -110,7 +114,7 @@ static enum rfc5444_result _cb_messagetlvs_end(
 /* definition of the RFC5444 reader components */
 static struct rfc5444_reader_tlvblock_consumer _olsrv2_message_consumer = {
   .order = RFC5444_MAIN_PARSER_PRIORITY,
-  .msg_id = RFC5444_MSGTYPE_TC,
+  .msg_id = RFC7181_MSGTYPE_TC,
   .block_callback = _cb_messagetlvs,
   .end_callback = _cb_messagetlvs_end,
 };
@@ -131,7 +135,7 @@ static struct rfc5444_reader_tlvblock_consumer_entry _olsrv2_message_tlvs[] = {
 
 static struct rfc5444_reader_tlvblock_consumer _olsrv2_address_consumer = {
   .order = RFC5444_MAIN_PARSER_PRIORITY,
-  .msg_id = RFC5444_MSGTYPE_TC,
+  .msg_id = RFC7181_MSGTYPE_TC,
   .addrblock_consumer = true,
   .block_callback = _cb_addresstlvs,
 };
@@ -153,7 +157,8 @@ static struct oonf_rfc5444_protocol *_protocol = NULL;
 static struct _olsrv2_data _current;
 
 /**
- * Initialize nhdp reader
+ * Initialize olsrv2 reader
+ * @param p RFC5444 protocol instance
  */
 void
 olsrv2_reader_init(struct oonf_rfc5444_protocol *p) {
@@ -357,7 +362,7 @@ _cb_addresstlvs(struct rfc5444_reader_tlvblock_context *context __attribute__((u
   OONF_DEBUG(LOG_OLSRV2_R, "Found address in tc: %s",
       netaddr_to_string(&buf, &context->addr));
 
-  os_route_init_sourcespec_prefix(&ssprefix, &context->addr);
+  os_routing_init_sourcespec_prefix(&ssprefix, &context->addr);
 
   for (tlv = _olsrv2_address_tlvs[IDX_ADDRTLV_LINK_METRIC].tlv;
       tlv; tlv = tlv->next_entry) {
@@ -442,7 +447,7 @@ _handle_gateways(struct rfc5444_reader_tlvblock_entry *tlv,
       netaddr_truncate(&ssprefix->dst, &ssprefix->dst);
       break;
     case RFC7181_SRCSPEC_DEF_GATEWAY:
-      os_route_init_sourcespec_src_prefix(ssprefix, addr);
+      os_routing_init_sourcespec_src_prefix(ssprefix, addr);
 
       /* truncate address */
       netaddr_truncate(&ssprefix->src, &ssprefix->src);
